@@ -2,22 +2,18 @@ use strict;
 use warnings;
 
 package Gherkin::Exceptions;
-$Gherkin::Exceptions::VERSION = '25.0.2';
-use overload
-    q{""}    => 'stringify',
-    fallback => 1;
-
-sub stringify { my $self  = shift; $self->message . "\n" }
+$Gherkin::Exceptions::VERSION = '27.0.0';
+sub stringify { my $self  = shift; $self->message }
 sub throw     { my $class = shift; die $class->new(@_) }
 
 # Parent of single and composite exceptions
 package Gherkin::Exceptions::Parser;
-$Gherkin::Exceptions::Parser::VERSION = '25.0.2';
+$Gherkin::Exceptions::Parser::VERSION = '27.0.0';
 use base 'Gherkin::Exceptions';
 
 # Composite exceptions
 package Gherkin::Exceptions::CompositeParser;
-$Gherkin::Exceptions::CompositeParser::VERSION = '25.0.2';
+$Gherkin::Exceptions::CompositeParser::VERSION = '27.0.0';
 use base 'Gherkin::Exceptions::Parser';
 use Class::XSAccessor accessors => [qw/errors/];
 
@@ -38,9 +34,14 @@ sub throw { my $class = shift; die $class->new(@_) }
 # Various non-composite exceptions
 #
 package Gherkin::Exceptions::SingleParser;
-$Gherkin::Exceptions::SingleParser::VERSION = '25.0.2';
+$Gherkin::Exceptions::SingleParser::VERSION = '27.0.0';
 use base 'Gherkin::Exceptions::Parser';
-use Class::XSAccessor accessors => [qw/location/];
+use Class::XSAccessor accessors => [qw/detailed_message location/];
+
+sub new {
+    my ( $class, %args ) = @_;
+    bless { %args }, $class;
+}
 
 sub message {
     my $self = shift;
@@ -51,7 +52,7 @@ sub message {
 }
 
 package Gherkin::Exceptions::NoSuchLanguage;
-$Gherkin::Exceptions::NoSuchLanguage::VERSION = '25.0.2';
+$Gherkin::Exceptions::NoSuchLanguage::VERSION = '27.0.0';
 use base 'Gherkin::Exceptions::SingleParser';
 use Class::XSAccessor accessors => [qw/language location/];
 
@@ -66,7 +67,7 @@ sub detailed_message {
 }
 
 package Gherkin::Exceptions::AstBuilder;
-$Gherkin::Exceptions::AstBuilder::VERSION = '25.0.2';
+$Gherkin::Exceptions::AstBuilder::VERSION = '27.0.0';
 use base 'Gherkin::Exceptions::SingleParser';
 use Class::XSAccessor accessors => [qw/location ast_message/];
 
@@ -82,7 +83,7 @@ sub detailed_message {
 }
 
 package Gherkin::Exceptions::UnexpectedEOF;
-$Gherkin::Exceptions::UnexpectedEOF::VERSION = '25.0.2';
+$Gherkin::Exceptions::UnexpectedEOF::VERSION = '27.0.0';
 use base 'Gherkin::Exceptions::SingleParser';
 use Class::XSAccessor accessors => [qw/location expected_token_types/];
 
@@ -102,7 +103,7 @@ sub detailed_message {
 }
 
 package Gherkin::Exceptions::UnexpectedToken;
-$Gherkin::Exceptions::UnexpectedToken::VERSION = '25.0.2';
+$Gherkin::Exceptions::UnexpectedToken::VERSION = '27.0.0';
 use base 'Gherkin::Exceptions::SingleParser';
 use Class::XSAccessor accessors =>
     [qw/location received_token_value expected_token_types state_comment/];
