@@ -1,5 +1,5 @@
 package Gherkin::TokenMatcher;
-$Gherkin::TokenMatcher::VERSION = '25.0.2';
+$Gherkin::TokenMatcher::VERSION = '27.0.0';
 use strict;
 use warnings;
 
@@ -79,7 +79,7 @@ sub match_ScenarioLine {
         ScenarioLine => $self->dialect->Scenario )
         or $self->_match_title_line(
             $token,
-            ScenarioLine => $self->dialect->ScenarioOutline );;
+            ScenarioLine => $self->dialect->ScenarioOutline );
 }
 
 sub match_BackgroundLine {
@@ -96,12 +96,13 @@ sub match_ExamplesLine {
 
 sub match_Language {
     my ( $self, $token ) = @_;
-    if ( $token->line->get_line_text =~ $LANGUAGE_RE ) {
+    if ( $token->line and $token->line->get_line_text =~ $LANGUAGE_RE ) {
         my $dialect_name = $1;
         $self->_set_token_matched( $token,
-            Language => { text => $dialect_name } );
-        $self->change_dialect( $dialect_name, $token->location );
-        return 1;
+                                   Language => { text => $dialect_name } );
+        local $@;
+        eval { $self->change_dialect( $dialect_name, $token->location ) };
+        return (1, $@);
     } else {
         return;
     }
@@ -109,14 +110,17 @@ sub match_Language {
 
 sub match_TagLine {
     my ( $self, $token ) = @_;
-    return unless $token->line->startswith('@');
+    return unless $token->line and $token->line->startswith('@');
+
+    my ($tags, $err) = $token->line->tags;
     $self->_set_token_matched( $token,
-        TagLine => { items => $token->line->tags } );
-    return 1;
+                               TagLine => { items => $tags } );
+    return (1, $err);
 }
 
 sub _match_title_line {
     my ( $self, $token, $token_type, $keywords ) = @_;
+    return unless $token->line;
 
     for my $keyword (@$keywords) {
         if ( $token->line->startswith_title_keyword($keyword) ) {
@@ -168,14 +172,14 @@ sub match_EOF {
 
 sub match_Empty {
     my ( $self, $token ) = @_;
-    return unless $token->line->is_empty;
+    return unless $token->line and $token->line->is_empty;
     $self->_set_token_matched( $token, Empty => { indent => 0 } );
     return 1;
 }
 
 sub match_Comment {
     my ( $self, $token ) = @_;
-    return unless $token->line->startswith('#');
+    return unless $token->line and $token->line->startswith('#');
 
     my $comment_text = $token->line->line_text;
     $comment_text =~ s/\r\n$//;    # Why?
@@ -187,6 +191,7 @@ sub match_Comment {
 
 sub match_Other {
     my ( $self, $token ) = @_;
+    return unless $token->line;
 
     # take the entire line, except removing DocString indents
     my $text = $token->line->get_line_text( $self->_indent_to_remove );
